@@ -3,9 +3,9 @@ use warnings;
 use MRO::Compat 'c3';
 
 package WebService::Shippo::Resource;
+require WebService::Shippo::Request;
 use Carp        ( 'croak' );
 use URI::Encode ( 'uri_encode' );
-use namespace::clean;
 use base ( 'WebService::Shippo::Object' );
 use constant DEFAULT_API_SCHEME    => 'https';
 use constant DEFAULT_API_HOST      => 'api.goshippo.com';
@@ -44,6 +44,7 @@ use constant DEFAULT_API_BASE_PATH => 'v1';
         my ( $class, $new_value ) = @_;
         return $value unless @_ > 1;
         $value = $new_value;
+        Shippo::Request->headers->{Authorization} = "ShippoToken $value";
         return $class;
     }
 }
@@ -121,10 +122,17 @@ sub url
         if $path;
     $url .= '/' . $resource
         if $resource;
-    $url .= '/' . uri_encode($id)
+    $url .= '/' . uri_encode( $id )
         if @_ > 1 && $id;
     $url .= '/';
     return $url;
 }
 
+BEGIN {
+    no warnings 'once';
+    # Forcing the dev to always use CPAN's perferred "WebService::Shippo"
+    # namespace is just cruel; allow the use of "Shippo", too.
+    *Shippo::Resource:: = *WebService::Shippo::Resource::;
+}
+
 1;
